.. _install-osa:

Deploying with OpenStack-Ansible
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

You can also deploy and set up Trove using `OpenStack-Ansible <https://docs.openstack.org/openstack-ansible/latest/>`_ by following
the `Trove role for OpenStack-Ansible <https://docs.openstack.org/openstack-ansible-os_trove/latest/>`_
which installs and configures Trove as part of your OpenStack deployment.
